# -*- coding: utf-8 -*-
import sys
from jinja2 import Template, Environment, meta, select_autoescape

DELIM = '_'
SPACE = ' '


def main_function(template_file):
    """Load the template, get values for variables
    and return it"""

    try:
        content = load(template_file)
        assert content, "Couldn't load template"

        template = Template(content)
        print(content)
        return template.render(context(content))
    except EOFError:
        sys.stderr.write("Error EOF")
    except OSError:
        sys.stderr.write("Error loading template file")
    except Exception as e:
        sys.stderr.write("Unexptected exception %s" % e)


def extract_variables(content: str) -> set:
    """Extract variables to fill in"""

    env = Environment(autoescape=select_autoescape(['html', 'xml']))

    return meta.find_undeclared_variables(env.parse(content))


def context(template):
    """Create template context from
    variables used in the template.

    Fill them out interactively using
    `InteractiveVariable`s
    """

    return {
        v.key: v.read()
        for v in
        [Variable(name) for name in extract_variables(template)]
    }


class Variable:
    """Representation of the template variable
    that will handle the user input"""
    def __init__(self, variable_name):
        self.key = variable_name
        self.message = self.key.replace(DELIM, SPACE)
        self.value = None

    def prompt(self):
        """Ask user for value"""
        return input(self.message + ": ").strip()

    def read(self):
        """Read the value and return it"""
        value_from_cli = self.prompt()

        self.value = value_from_cli
        return value_from_cli


def load(template):
    """Read the contents of the template file"""
    with open(template) as f:
        return f.read()



# -*- coding: utf-8 -*-
"""Command line function."""
import sys
import click

from paczekfiller.paczekfiller import main as fry


def write(filename, contents):
    with open(filename, 'w') as file:
        file.write(contents)


@click.command()
@click.argument('paczek')
@click.argument('output_file')
def main(output_file, paczek):
    """Console script for Pączek filler."""

    write(output_file, fry(paczek))


if __name__ == "__main__":
    sys.exit(main())  # pragma: no cover



# -*- coding: utf-8 -*-
import io
import os
import re

from setuptools import find_packages
from setuptools import setup


def read(filename):
    filename = os.path.join(os.path.dirname(__file__), filename)
    text_type = type(u"")
    with io.open(filename, mode="r", encoding='utf-8') as fd:
        return re.sub(text_type(r':[a-z]+:`~?(.*?)`'), text_type(r'``\1``'), fd.read())

setup(
    name="paczekfiller",
    version="0.1.1",
    url="https://github.com/kr1surb4n/paczekfiller",
    license='MIT',

    author="Kris Urbanski",
    author_email="kris@whereibend.space",

    description="Pączek filler - simple script for filling out single template files",
    long_description=read("README.md"),
    long_description_content_type="text/markdown",

    packages=find_packages(exclude=('tests', 'docs', 'htmlcov',)),

    install_requires=['Click', 'Jinja2'],
    extras_require={
        'fzf':  ["fzf"],
    },
    scripts=['bin/paczek'],
    entry_points={'console_scripts': [
        'paczekfiller = paczekfiller.cli:main',
    ]},
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
)
